Learn R Programming

FSAdata (version 0.3.0)

AHerringChile: Ages and lengths of Araucanian Herring from Chilean waters.

Description

Ages and lengths of Araucanian Herring (Strangomera bentincki) from Chilean waters.

Arguments

source

extracted from figure 9 of Cubillos, L.A., D.F. Arcosa, D.A. Bucareya, M.T. Canalesa. 2001. Seasonal growth of small pelagic fish off Talcahuano, Chile (37S, 73W): a consequence of their reproductive strategy to seasonal upwelling? Aquatic Living Resources, 14:115-124.

Topic(s)

  • Growth
  • Seasonal Growth
  • von Bertalanffy
  • Somers model

concept

'Seasonal Growth' 'von Bertalanffy' Somers

Examples

Run this code
data(AHerringChile)
str(AHerringChile)
head(AHerringChile)
plot(len~age,data=AHerringChile)

Run the code above in your browser using DataLab