Learn R Programming

FSAdata (version 0.3.0)

AlewifeLH: Ages of Lake Huron Alewife assigned from otoliths and scales.

Description

Ages of Alewife (Alosa pseudoharengus) assessed from otoliths and scales.

Arguments

source

Hoenig, J.M., M.J. Morgan, and C.A. Brown. 1995. Analysing differences between two age determination methods by tests of symmetry. Canadian Journal of Fisheries And Aquatic Systems, 52:364-368.

Topic(s)

  • Age comparison
  • Age precision
  • Age Bias
  • Ageing error

concept

Age Precision Bias 'Age Comparison'

Examples

Run this code
data(AlewifeLH)
str(AlewifeLH)
head(AlewifeLH)
plot(scales~otoliths,data=AlewifeLH)
xtabs(~otoliths+scales,data=AlewifeLH)

Run the code above in your browser using DataLab