Learn R Programming

FSAdata (version 0.3.0)

KingCrabAK: Stock and recruitment data for Red King Crab in Alaska.

Description

Stock and recruitment data for Red King Crab (Paralithodes camtschaticus) from the northern Gulf of Alaska around Kodiak Island by brood year, 1960-2004.

Arguments

source

Data from table 1 in Bechtol W.R. and G.H. Kruse. 2009. Analysis of a stock-recruit relationship for red king crab off Kodiak Island Alaska. Marine and Coastal Fisheries: Dynamics Management and Ecosystem Science 1:29-44.

Topic(s)

  • Stock-recruit

concept

'Stock-Recruit'

Examples

Run this code
data(KingCrabAK)
str(KingCrabAK)
head(KingCrabAK)
op <- par(mfrow=c(1,2),pch=19)
plot(recruits~year,data=KingCrabAK,type="l")
plot(recruits~adults,data=KingCrabAK)
par(op)

Run the code above in your browser using DataLab