Learn R Programming

FSAdata (version 0.3.0)

LakeTroutEggs: Length and egg deposition of Lake Superior Lake Trout.

Description

Length and egg deposition of Lake Superior Lake Trout (Salvelinus namaycush).

Arguments

source

Schram, S.T. 1993. Fecundity and egg deposition of a wild Lake Superior Lake Trout stock. Wisconsin Department of Natural Resources, Fisheries Management Report no. 149.

Examples

Run this code
data(LakeTroutEggs)
str(LakeTroutEggs)
head(LakeTroutEggs)
plot(eggs~tl,data=LakeTroutEggs)

Run the code above in your browser using DataLab