Learn R Programming

FSAdata (version 0.3.0)

LakeTroutGIS: Stock and recruitment data for Lake Trout from Gull Island Shoal, Lake Superior, 1964-1991.

Description

Lake trout (Salvelinus namaycush) stock and recruitment by year at Gull Island Shoal, Lake Superior, 1964-1991.

Arguments

source

from Schram, S.T., J.H. Selgeby, C.R. Bronte, and B.L. Swanson. 1995. Population recovery and natural recruitment of Lake Trout at Gull Island Shoal, Lake Superior, 1964-1992. Journal of Great Lakes Research. 21(supp.1):225-232. Obtained from http://ram.biology.dal.ca/~myers/data.html{Ransom Myers online database}

Topic(s)

  • Stock-recruit

concept

'Stock-Recruit'

Examples

Run this code
data(LakeTroutGIS)
str(LakeTroutGIS)
head(LakeTroutGIS)
op <- par(mfrow=c(1,2))
plot(recruits~year,data=LakeTroutGIS,type="l")
plot(recruits~stock,data=LakeTroutGIS)
par(op)

Run the code above in your browser using DataLab