Learn R Programming

FSAdata (version 0.3.0)

RBSmeltErie: Recruitment time-series for Rainbow Smelt in Lake Erie, 1977-1996.

Description

Rainbow Smelt (Osmerus mordax) recruitment time series for Lake Erie, 1977-1996.

Arguments

source

from Ontario Ministry of Natural Resources, Fish and Wildlife Branch, 1997. Lake Erie fisheries report 1996. Lake Erie Committee Meeting, Great Lakes Fishery Commission, Ann Arbor, Michigan. pp 26. Obtained from http://ram.biology.dal.ca/~myers/data.html{Ransom Myers online database}.

Topic(s)

  • Recruitment time-series

concept

Recruitment

Examples

Run this code
data(RBSmeltErie)
str(RBSmeltErie)
head(RBSmeltErie)
plot(recruits~year,data=RBSmeltErie,type="l")

Run the code above in your browser using DataLab