Learn R Programming

FSAdata (version 0.3.0)

SardineChile: Ages and lengths of two year-classes of Sardine from Chilean waters.

Description

Ages (in months) and total lengths of two year-classes of Sardine (Strangomera bentincki) from central Chilean waters.

Arguments

source

Directly from the authors of Cubillos, L.A., D.F. Arcosa, D.A. Bucareya, M.T. Canalesa. 2001. Seasonal growth of small pelagic fish off Talcahuano, Chile (37S, 73W): a consequence of their reproductive strategy to seasonal upwelling? Aquatic Living Resources, 14:115-124. Data were in Figure 9.

Topic(s)

  • Growth
  • Seasonal Growth
  • von Bertalanffy
  • Somers model

concept

Growth 'von Bertalanffy' Somers 'Seasonal Growth'

Examples

Run this code
data(SardineChile)
str(SardineChile)
head(SardineChile)
SardineChile$age <- SardineChile$age.mon/12
plot(tl.cm~age,data=SardineChile)

Run the code above in your browser using DataLab