Learn R Programming

FSAdata (version 0.3.0)

SardineLK: Ages and lengths of larval Lake Tanganyika Sardine.

Description

Ages (days) and total lengths of larval Lake Tanganyika Sardine (Limnothrissa miodon) from Lake Kariba.

Arguments

source

Extracted (approximately) from Figure 3 of Mtsambiwa, M.Z. 1992. http://www.fao.org/docrep/005/v2648e/V2648E06.htm{Fitting a von Bertalanffy growth model to length at age data for larval Limnothrissa miodon from Lake Kariba.} Paper presented at the Symposium on biology, stock assessment, and exploitation of small pelagic fish species in the African Great Lakes region.

Topic(s)

  • Growth
  • von Bertalanffy

concept

Growth 'von Bertalanffy'

Examples

Run this code
data(SardineLK)
str(SardineLK)
head(SardineLK)
plot(tl~days,data=SardineLK)

Run the code above in your browser using DataLab