Learn R Programming

FSAdata (version 0.3.0)

Deckeretal1999: Catches in removal events of Cutthroat Trout and Coho Salmon in Little Stawamus Creek (British Columbia, Canada) in 1997.

Description

Catches of Coho Salmon (Oncorhynchus kisutch) and Cutthroat Trout (Oncorhynchus clarki) in consecutive removal events at various locations in Little Stawamus Creek (British Columbia, Canada) in 1997.

Arguments

source

From Appendix 2a and 2b in Decker, A.S., J.M. Bratty, S.C. Riley, and J. Korman. 1999. http://www.dfo-mpo.gc.ca/Library/239481.pdf{Estimating standing stock of juvenile coho salmon (Oncorhynchus kisutch) and cutthroat trout (Oncorhynchus clarki) in a small stream: a comparison of sampling designs.} Canadian Technical Report of Fisheries and Aquatic Sciences 2282. 24 pp.

Topic(s)

  • Population size
  • Abundance
  • Removal

concept

Abundance 'Population Size' Removal

Examples

Run this code
data(Deckeretal1999)
str(Deckeretal1999)
head(Deckeretal1999)

## extract data for one sampling location (e.g., 3rd row)
Deckeretal1999[3,]

Run the code above in your browser using DataLab