Learn R Programming

FSAdata (version 0.3.0)

GreensCreekMine: Catches in removal events of Coho Salmon and Dolly Varden Char at various locations near the Greens Creek (AK) Mine site.

Description

Catches in removal events of Coho Salmon (Oncorhynchus kisutch) and Dolly Varden Char (Salvelinus malma) at various locations near the Greens Creek (AK) Mine site.

Arguments

source

From Appendix C1 of Kanouse, K.M. and B.P. Brewster. 2012. http://dnr.alaska.gov/mlw/mining/largemine/greenscreek/pdf/gc2012bio.pdf{Aquatic Biomonitoring at Greens Creek Mine, 2012.} Alaska Department of Fish and Game Technical Report No. 12-11.

Topic(s)

  • Population size
  • Abundance
  • Removal

concept

Abundance 'Population Size' Removal

Details

Reaches were isolated by natural features, such as shallow riffles. The sample reaches were saturated with 6.35 mm (0.25 in) minnow traps baited with whirl packs containing disinfected salmon eggs. The traps were deployed for 1.5 h and then retrieved where each fish was transferred into a plastic bucket, and the trap was re-baited ans re-set for another 1.5 h soak. In between trapping events, fish were processed -- measured and recorded FL to the nearest 1 mm, weight to the nearest 0.1 g, and species identified. Captured fish were retained during the sample period and returned alive after all three passes were complete.

Examples

Run this code
data(GreensCreekMine)
str(GreensCreekMine)
head(GreensCreekMine)

## extract data for one location, year, and species (e.g., 3rd row)
GreensCreekMine[3,]

Run the code above in your browser using DataLab